==> zego_zpns-2.3.0%2B1.tar.gz: lib/src/call_kit_event_handler.dart <==
import '../zego_zpns.dart';

class CallKitEventHandler{


  ///This method is invoked when a push notification has been received for the specified PKPushType.
  ///[payload] The push payload sent by a developer via APNS server API.
  ///[completion] This completion handler should be called to signify the completion of payload processing.
  static void Function(Map payload,Function completion)? didReceiveIncomingPushWithPayload;

  /// Called when the provider has been reset. Delegates must respond to this callback by cleaning up all internal call state (disconnecting communication channels, releasing network resources, etc.). This callback can be treated as a request to end all calls without the need to respond to any actions
  static void Function()? providerDidReset;

  /// Called when the provider has been fully created and is ready to send actions and receive updates
  static void Function()? providerDidBegin;

  /// Called when the provider's audio session activation state changes.
  static void Function()? didActivateAudioSession;

  static void Function()? didDeactivateAudioSession;


  /// Called when an action was not performed in time and has been inherently failed. Depending on the action, this timeout may also force the call to end. An action that has already timed out should not be fulfilled or failed by the provider delegate
  static void Function(CXAction action)? timedOutPerformingAction;


  /// each perform*CallAction method is called sequentially for each action in the transaction
  static void Function(CXAction action)? performStartCallAction;

  static void Function(CXAction action)? performAnswerCallAction;

  static void Function(CXAction action)? performEndCallAction;

  static void Function(CXAction action)? performSetHeldCallAction;

  static void Function(CXAction action)? performSetMutedCallAction;

  static void Function(CXAction action)? performSetGroupCallAction;

  static void Function(CXAction action)? performPlayDTMFCallAction;
}

==> zego_zpns-2.4.0%2B1.tar.gz: lib/src/call_kit_event_handler.dart <==
import '../zego_zpns.dart';

class CallKitEventHandler{


  ///This method is invoked when a push notification has been received for the specified PKPushType.
  ///[extras] The push extras sent by a developer via APNS server API.
  static void Function(Map extras, UUID uuid)? didReceiveIncomingPush;

  /// Called when the provider has been reset. Delegates must respond to this callback by cleaning up all internal call state (disconnecting communication channels, releasing network resources, etc.). This callback can be treated as a request to end all calls without the need to respond to any actions
  static void Function()? providerDidReset;

  /// Called when the provider has been fully created and is ready to send actions and receive updates
  static void Function()? providerDidBegin;

  /// Called when the provider's audio session activation state changes.
  static void Function()? didActivateAudioSession;

  static void Function()? didDeactivateAudioSession;


  /// Called when an action was not performed in time and has been inherently failed. Depending on the action, this timeout may also force the call to end. An action that has already timed out should not be fulfilled or failed by the provider delegate
  static void Function(CXAction action)? timedOutPerformingAction;


  /// each perform*CallAction method is called sequentially for each action in the transaction
  static void Function(CXAction action)? performStartCallAction;

  static void Function(CXAction action)? performAnswerCallAction;

  static void Function(CXAction action)? performEndCallAction;

  static void Function(CXAction action)? performSetHeldCallAction;

  static void Function(CXSetMutedCallAction action)? performSetMutedCallAction;

  static void Function(CXAction action)? performSetGroupCallAction;

  static void Function(CXAction action)? performPlayDTMFCallAction;
}
